nbxmpp.proxy_connectors

Package nbxmpp :: Module proxy_connectors |
[hide private]
[frames] | no frames]

# Module proxy_connectors

source code

Module containing classes for proxy connecting. So far its HTTP CONNECT and SOCKS5 proxy

Authentication to NTLM (Microsoft implementation) proxies can be next.

Classes | [hide private]
| ProxyConnector Interface for proxy-connecting object - when tunnneling XMPP over proxies, some connecting process usually has to be done before opening stream. Proxy connectors are used right after TCP connection is estabilished
| HTTPCONNECTConnector
| SOCKS5Connector SOCKS5 proxy connection class. Allows to use SOCKS5 proxies with (optionally) simple authentication (only USERNAME/PASSWORD auth)

Variables | [hide private]
| log = `logging.getLogger('nbxmpp.proxy_connectors')`
| __package__ = ``'``nbxmpp``'``

Imports: struct, socket, base64, logging

Variables Details | [hide private]

  ### log Value:
      logging.getLogger('nbxmpp.proxy_connectors')

  ### __package__ Value:
      'nbxmpp'